@@ -3,7 +3,6 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
-#undef HAVE_GOBJECT
 #undef HAVE_ODBC
 #undef HAVE_MYSQL
 #undef HAVE_INTERBASE
@@ -16,5 +15,3 @@
 #undef SYBASE_DEBUG
 #undef HAVE_POSTGRES
 #undef HAVE_CAMEL
-
-#undef HAVE_PERL
