@@ -16,19 +16,19 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-namespace gda
-{
-	class Batch;
-	class Command;
-	class Connection;
-	class Error;
-	class ErrorList;
-	class Field;
-	class Recordset;
-	class Value;
-};
+#ifndef __gda_bindings_cpp_gdaIncludesH
+#define __gda_bindings_cpp_gdaIncludesH
 
+extern "C" {
+
+// hack to remove nasty compiler warnings
+//
+//
+#define export
+
+#include "glib.h"
 #include "gda-client.h"
+
 #include "gda-batch.h"
 #include "gda-command.h"
 #include "gda-connection.h"
@@ -36,6 +36,12 @@ namespace gda
 #include "gda-field.h"
 #include "gda-recordset.h"
 
+#undef export
+}
+
+#include <string>
+#include <vector>
+
 #include "gdaBatch.h"
 #include "gdaCommand.h"
 #include "gdaConnection.h"
@@ -44,3 +50,5 @@ namespace gda
 #include "gdaField.h"
 #include "gdaRecordset.h"
 #include "gdaValue.h"
+
+#endif // __gda_bindings_cpp_gdaIncludesH
