@@ -20,59 +20,41 @@
 
 #include "config.h"
 #include "gda-command.h"
+#include "gda-corba.h"
 
 enum {
 	GDA_COMMAND_LAST_SIGNAL
 };
 
-typedef struct _Parameter {
-	gchar* name;
-	GDA_Value* value;
+typedef struct _Parameter
+{
+	gchar *name;
+	GDA_Value *value;
 	GDA_ParameterDirection inout;
-} Parameter;
+}
+Parameter;
 
 static gint gda_command_signals[GDA_COMMAND_LAST_SIGNAL] = { 0, };
 
-#ifdef HAVE_GOBJECT
-static void gda_command_class_init (GdaCommandClass *klass, gpointer data);
-static void gda_command_init       (GdaCommand *cmd, GdaCommandClass *klass);
-#else
-static void gda_command_class_init (GdaCommandClass *klass);
-static void gda_command_init       (GdaCommand *cmd);
-#endif
+static void gda_command_class_init (GdaCommandClass * klass);
+static void gda_command_init (GdaCommand * cmd);
+static void gda_command_destroy (GtkObject * object);
 
 static void
-release_connection_object (GdaCommand* cmd, GdaConnection* cnc) {
-	cmd->connection->commands = g_list_remove(cmd->connection->commands, cmd);
+release_connection_object (GdaCommand * cmd, GdaConnection * cnc)
+{
+	g_return_if_fail (GDA_IS_COMMAND (cmd));
+	g_return_if_fail (GDA_IS_CONNECTION (cmd->connection));
+
+	cmd->connection->commands =
+		g_list_remove (cmd->connection->commands, cmd);
 }
 
-#ifdef HAVE_GOBJECT
-GType
-gda_command_get_type (void) {
-	static GType type = 0;
-	
-	if (!type) {
-		GTypeInfo info = {
-			sizeof (GdaCommandClass),               /* class_size */
-			NULL,                                    /* base_init */
-			NULL,                                    /* base_finalize */
-			(GClassInitFunc) gda_command_class_init, /* class_init */
-			NULL,                                    /* class_finalize */
-			NULL,                                    /* class_data */
-			sizeof (GdaCommand),                    /* instance_size */
-			0,                                       /* n_preallocs */
-			(GInstanceInitFunc) gda_command_init,    /* instance_init */
-			NULL,                                    /* value_table */
-		};
-		type = g_type_register_static (G_TYPE_OBJECT, "GdaCommand", &info, 0);
-	}
-	return type;
-}
-#else
 guint
-gda_command_get_type (void) {
+gda_command_get_type (void)
+{
 	static guint gda_command_type = 0;
-	
+
 	if (!gda_command_type) {
 		GtkTypeInfo gda_command_info = {
 			"GdaCommand",
@@ -80,33 +62,36 @@ gda_command_get_type (void) {
 			sizeof (GdaCommandClass),
 			(GtkClassInitFunc) gda_command_class_init,
 			(GtkObjectInitFunc) gda_command_init,
-			(GtkArgSetFunc)NULL,
-			(GtkArgSetFunc)NULL,
+			(GtkArgSetFunc) NULL,
+			(GtkArgSetFunc) NULL,
 		};
-		gda_command_type = gtk_type_unique(gtk_object_get_type(), &gda_command_info);
+		gda_command_type =
+			gtk_type_unique (gtk_object_get_type (),
+					 &gda_command_info);
 	}
 	return gda_command_type;
 }
-#endif
-
-#ifdef HAVE_GOBJECT
-static void
-gda_command_class_init (GdaCommandClass *klass, gpointer data) {
-}
-#else
-static void
-gda_command_class_init (GdaCommandClass* klass) {
-	GtkObjectClass* object_class = (GtkObjectClass*) klass;
-}
-#endif
 
 static void
-#ifdef HAVE_GOBJECT
-gda_command_init (GdaCommand *cmd, GdaCommandClass *klass)  {
-#else
-gda_command_init (GdaCommand* cmd) {
-#endif
-	g_return_if_fail(IS_GDA_COMMAND(cmd));
+gda_command_class_init (GdaCommandClass * klass)
+{
+	GtkObjectClass *object_class = (GtkObjectClass *) klass;
+
+	object_class->destroy = gda_command_destroy;
+}
+
+static void
+gda_command_init (GdaCommand * cmd)
+{
+	g_return_if_fail (GDA_IS_COMMAND (cmd));
+
+	cmd->command = CORBA_OBJECT_NIL;
+	cmd->orb = gda_corba_get_orb ();
+	cmd->connection = NULL;
+	cmd->text = NULL;
+	cmd->type = GDA_TypeNull;
+	cmd->parameters = NULL;
+	cmd->text_pending = cmd->type_pending = FALSE;
 }
 
 /**
@@ -117,12 +102,40 @@ gda_command_init (GdaCommand* cmd) {
  * Returns: a pointer to the command object
  */
 GdaCommand *
-gda_command_new (void) {
-#ifdef HAVE_GOBJECT
-	return GDA_COMMAND (g_object_new (GDA_TYPE_COMMAND, NULL));
-#else
-	return GDA_COMMAND(gtk_type_new(gda_command_get_type()));
-#endif
+gda_command_new (void)
+{
+	return GDA_COMMAND (gtk_type_new (GDA_TYPE_COMMAND));
+}
+
+static void
+gda_command_destroy (GtkObject * object)
+{
+	CORBA_Environment ev;
+	GtkObjectClass *parent_class;
+	GdaCommand *cmd = (GdaCommand *) object;
+
+	g_return_if_fail (GDA_IS_COMMAND (cmd));
+
+	if (cmd->connection && cmd->connection->commands)
+		release_connection_object (cmd, cmd->connection);
+	else {
+		if (cmd->connection && !cmd->connection->commands)
+			g_error ("gda_command_free: connection object has no command list");
+	}
+	if (cmd->text)
+		g_free (cmd->text);
+
+	CORBA_exception_init (&ev);
+	if (!CORBA_Object_is_nil (cmd->command, &ev)) {
+		CORBA_Object_release (cmd->command, &ev);
+		gda_connection_corba_exception (gda_command_get_connection
+						(cmd), &ev);
+	}
+	CORBA_exception_free (&ev);
+
+	parent_class = gtk_type_class (gtk_object_get_type ());
+	if (parent_class && parent_class->destroy)
+		parent_class->destroy (object);
 }
 
 /**
@@ -131,32 +144,11 @@ gda_command_new (void) {
  *
  * This function frees the memory of command object and
  * cuts the association with its connection object.
- *
  */
 void
-gda_command_free (GdaCommand* cmd) {
-	CORBA_Environment ev;
-	
-	g_return_if_fail(IS_GDA_COMMAND(cmd));
-	
-	if (cmd->connection && cmd->connection->commands)
-		release_connection_object(cmd, cmd->connection);
-	else {
-		if (cmd->connection && !cmd->connection->commands)
-			g_error("gda_command_free: connection object has no command list");
-	}
-	if (cmd->text) g_free(cmd->text);
-	
-	CORBA_exception_init(&ev);
-	if (!CORBA_Object_is_nil(cmd->command, &ev)) {
-		CORBA_Object_release(cmd->command, &ev);
-		gda_connection_corba_exception(gda_command_get_connection(cmd), &ev);
-	}
-#ifdef HAVE_GOBJECT
-	g_object_unref (G_OBJECT (cmd));
-#else
+gda_command_free (GdaCommand * cmd)
+{
 	gtk_object_destroy (GTK_OBJECT (cmd));
-#endif
 }
 
 /**
@@ -171,34 +163,46 @@ gda_command_free (GdaCommand* cmd) {
  *
  * Returns: -1 on error, 0 on success
  */
-gint
-gda_command_set_connection (GdaCommand* cmd, GdaConnection* cnc) {
+void
+gda_command_set_connection (GdaCommand * cmd, GdaConnection * cnc)
+{
 	CORBA_Environment ev;
-	
-	g_return_val_if_fail(IS_GDA_COMMAND(cmd), -1);
-	g_return_val_if_fail(IS_GDA_CONNECTION(cnc), -1);
-	g_return_val_if_fail(cnc->connection != 0, -1);
-	
+
+	g_return_if_fail (GDA_IS_COMMAND (cmd));
+	g_return_if_fail (GDA_IS_CONNECTION (cnc));
+	g_return_if_fail (cnc->connection != 0);
+
+	/* clean up */
+
 	if (cmd->connection) {
-		release_connection_object(cmd, cmd->connection);
+		release_connection_object (cmd, cmd->connection);
 	}
 	cmd->connection = cnc;
-	
-	CORBA_exception_init(&ev);
-	cmd->command = GDA_Connection_createCommand(cnc->connection, &ev);
-	if (gda_connection_corba_exception(gda_command_get_connection(cmd), &ev) < 0) {
-		cmd->connection = NULL;
-		return -1;
+
+	CORBA_exception_init (&ev);
+	if (cmd->command != CORBA_OBJECT_NIL) {
+		CORBA_Object_release (cmd->command, &ev);
+		cmd->command = NULL;
 	}
-	cmd->connection->commands = g_list_append(cmd->connection->commands, cmd);
+
+	/* get a new GDA::Command object */
+	cmd->command = GDA_Connection_createCommand (cnc->connection, &ev);
+	if (gda_connection_corba_exception
+	    (gda_command_get_connection (cmd), &ev) < 0) {
+		cmd->connection = NULL;
+		cmd->command = CORBA_OBJECT_NIL;
+		return;
+	}
+	cmd->connection->commands =
+		g_list_append (cmd->connection->commands, cmd);
 	if (cmd->text_pending) {
-		GDA_Command__set_text(cmd->command, cmd->text, &ev);
-		gda_connection_corba_exception(gda_command_get_connection(cmd), &ev);
+		GDA_Command__set_text (cmd->command, cmd->text, &ev);
+		gda_connection_corba_exception (gda_command_get_connection
+						(cmd), &ev);
 		cmd->text_pending = 0;
 	}
-	return 0;
 }
-  
+
 /**
  * gda_command_get_connection:
  * @cmd: the command object
@@ -208,9 +212,9 @@ gda_command_set_connection (GdaCommand* cmd, GdaConnection* cnc) {
  * Returns: a pointer to the #gda_Connection object
  */
 GdaConnection *
-gda_command_get_connection (GdaCommand* cmd) {
-	g_return_val_if_fail(IS_GDA_COMMAND(cmd), NULL);
-
+gda_command_get_connection (GdaCommand * cmd)
+{
+	g_return_val_if_fail (GDA_IS_COMMAND (cmd), NULL);
 	return cmd->connection;
 }
 
@@ -226,22 +230,24 @@ gda_command_get_connection (GdaCommand* cmd) {
  *
  */
 void
-gda_command_set_text (GdaCommand* cmd, gchar* text) {
+gda_command_set_text (GdaCommand * cmd, gchar * text)
+{
 	CORBA_Environment ev;
-	
-	g_return_if_fail(IS_GDA_COMMAND(cmd));
-	
+
+	g_return_if_fail (GDA_IS_COMMAND (cmd));
+
 	if (cmd->text)
-		g_free(cmd->text);
-	cmd->text = g_strdup(text);
+		g_free (cmd->text);
+	cmd->text = g_strdup (text);
 	if (!cmd->command) {
-		g_print("No CORBA command yet allocated, setting to pending");
+		g_print ("No CORBA command yet allocated, setting to pending");
 		cmd->text_pending = 1;
 	}
 	else {
-		CORBA_exception_init(&ev);
-		GDA_Command__set_text(cmd->command, text, &ev);
-		gda_connection_corba_exception(gda_command_get_connection(cmd), &ev);
+		CORBA_exception_init (&ev);
+		GDA_Command__set_text (cmd->command, text, &ev);
+		gda_connection_corba_exception (gda_command_get_connection
+						(cmd), &ev);
 	}
 }
 
@@ -255,18 +261,19 @@ gda_command_set_text (GdaCommand* cmd, gchar* text) {
  * Returns: a reference to the command string.
  */
 gchar *
-gda_command_get_text (GdaCommand* cmd) {
-	gchar* txt;
+gda_command_get_text (GdaCommand * cmd)
+{
+	gchar *txt;
 	CORBA_Environment ev;
-	
-	g_return_val_if_fail(IS_GDA_COMMAND(cmd), 0);
-	
+
+	g_return_val_if_fail (GDA_IS_COMMAND (cmd), 0);
+
 	if (!cmd->command) {
-		g_print("No CORBA command_yet allocated, using pending value\n");
+		g_print ("No CORBA command_yet allocated, using pending value\n");
 		return cmd->text;
 	}
-	CORBA_exception_init(&ev);
-	txt = GDA_Command__get_text(cmd->command, &ev);
+	CORBA_exception_init (&ev);
+	txt = GDA_Command__get_text (cmd->command, &ev);
 	return txt;
 }
 
@@ -282,20 +289,22 @@ gda_command_get_text (GdaCommand* cmd) {
  *
  */
 void
-gda_command_set_cmd_type (GdaCommand* cmd, GDA_CommandType type) {
+gda_command_set_cmd_type (GdaCommand * cmd, GDA_CommandType type)
+{
 	CORBA_Environment ev;
-	
-	g_return_if_fail(IS_GDA_COMMAND(cmd));
-	
+
+	g_return_if_fail (GDA_IS_COMMAND (cmd));
+
 	if (!cmd->command) {
-		g_print("No CORBA command yet allocated, setting to pending");
+		g_print ("No CORBA command yet allocated, setting to pending");
 		cmd->type_pending = 1;
 		cmd->type = type;
 	}
 	else {
-		CORBA_exception_init(&ev);
-		GDA_Command__set_type(cmd->command, type, &ev);
-		gda_connection_corba_exception(gda_command_get_connection(cmd), &ev);
+		CORBA_exception_init (&ev);
+		GDA_Command__set_type (cmd->command, type, &ev);
+		gda_connection_corba_exception (gda_command_get_connection
+						(cmd), &ev);
 	}
 }
 
@@ -308,58 +317,69 @@ gda_command_set_cmd_type (GdaCommand* cmd, GDA_CommandType type) {
  * Returns: the type of the command
  */
 GDA_CommandType
-gda_command_get_cmd_type (GdaCommand* cmd) {
+gda_command_get_cmd_type (GdaCommand * cmd)
+{
 	GDA_CommandType type;
 	CORBA_Environment ev;
-	
-	g_return_val_if_fail(IS_GDA_COMMAND(cmd), 0);
-	
+
+	g_return_val_if_fail (GDA_IS_COMMAND (cmd), 0);
+
 	if (!cmd->command) {
-		g_print("No CORBA command_yet allocated, using pending value\n");
+		g_print ("No CORBA command_yet allocated, using pending value\n");
 		return cmd->type;
 	}
-	CORBA_exception_init(&ev);
-	type = GDA_Command__get_type(cmd->command, &ev);
+	CORBA_exception_init (&ev);
+	type = GDA_Command__get_type (cmd->command, &ev);
+	gda_connection_corba_exception (gda_command_get_connection (cmd),
+					&ev);
+	CORBA_exception_free (&ev);
+
 	return type;
 }
 
 
-GDA_CmdParameterSeq*
-__gda_command_get_params (GdaCommand* cmd) {
-	GDA_CmdParameterSeq*      corba_parameters;
-	gint                      parameter_count;
-	GList*                    ptr;
-	GDA_CmdParameter*         corba_parameter;
-	gint                      idx;
-	
-	corba_parameters = GDA_CmdParameterSeq__alloc();
-	parameter_count = cmd->parameters ? g_list_length(cmd->parameters) : 0;
-	corba_parameters->_buffer = CORBA_sequence_GDA_CmdParameter_allocbuf(parameter_count);
+GDA_CmdParameterSeq *
+__gda_command_get_params (GdaCommand * cmd)
+{
+	GDA_CmdParameterSeq *corba_parameters;
+	gint parameter_count;
+	GList *ptr;
+	GDA_CmdParameter *corba_parameter;
+	gint idx;
+
+	corba_parameters = GDA_CmdParameterSeq__alloc ();
+	parameter_count =
+		cmd->parameters ? g_list_length (cmd->parameters) : 0;
+	corba_parameters->_buffer =
+		CORBA_sequence_GDA_CmdParameter_allocbuf (parameter_count);
 	corba_parameters->_length = parameter_count;
-	
+
 	if (parameter_count) {
 		ptr = cmd->parameters;
 		idx = 0;
-		while(ptr) {
-			GDA_Value* value;
-			Parameter* parameter;
-			
+		while (ptr) {
+			GDA_Value *value;
+			Parameter *parameter;
+
 			parameter = ptr->data;
 			corba_parameter = &(corba_parameters->_buffer[idx]);
 			corba_parameter->dir = parameter->inout;
 			if (parameter->name) {
-				corba_parameter->name = CORBA_string_dup(parameter->name);
+				corba_parameter->name =
+					CORBA_string_dup (parameter->name);
 			}
-			else corba_parameter->name = 0;
-			
+			else
+				corba_parameter->name = 0;
+
 			value = parameter->value;
 			if (!(corba_parameter->value._d = value ? 0 : 1)) {
-				corba_parameter->value._u.v = *((*parameter).value);
+				corba_parameter->value._u.v =
+					*((*parameter).value);
 			}
 			else {
-				g_print("Got NULL param value\n");
+				g_print ("Got NULL param value\n");
 			}
-			ptr = g_list_next(ptr);
+			ptr = g_list_next (ptr);
 			idx++;
 		}
 	}
@@ -381,18 +401,20 @@ __gda_command_get_params (GdaCommand* cmd) {
  * Returns: a pointer to a recordset or a NULL pointer if there was an error.
  */
 GdaRecordset *
-gda_command_execute (GdaCommand* cmd, gulong* reccount, gulong flags) {
+gda_command_execute (GdaCommand * cmd, gulong * reccount, gulong flags)
+{
 	gint rc;
-	GdaRecordset* rs;
-	
-	g_return_val_if_fail(IS_GDA_COMMAND(cmd), 0);
-	g_return_val_if_fail(reccount != NULL, 0);
-	g_return_val_if_fail(cmd->connection != NULL, 0);
-	
-	rs = GDA_RECORDSET(gda_recordset_new());
-	rc = gda_recordset_open(rs, cmd, GDA_OPEN_FWDONLY, GDA_LOCK_OPTIMISTIC, flags);
+	GdaRecordset *rs;
+
+	g_return_val_if_fail (GDA_IS_COMMAND (cmd), 0);
+	g_return_val_if_fail (reccount != NULL, 0);
+	g_return_val_if_fail (cmd->connection != NULL, 0);
+
+	rs = GDA_RECORDSET (gda_recordset_new ());
+	rc = gda_recordset_open (rs, cmd, GDA_OPEN_FWDONLY,
+				 GDA_LOCK_OPTIMISTIC, flags);
 	if (rc < 0) {
-		gda_recordset_free(rs);
+		gda_recordset_free (rs);
 		return NULL;
 	}
 	*reccount = rs->affected_rows;
@@ -430,56 +452,18 @@ gda_command_execute (GdaCommand* cmd, gulong* reccount, gulong flags) {
  * value parameter if it's not a simple data type (integer, float, ...)
  */
 void
-gda_command_create_parameter (GdaCommand* cmd,
-                              gchar* name,
-                              GDA_ParameterDirection inout,
-                              GDA_Value* value) {
-	Parameter* param;
-	
-	g_return_if_fail(IS_GDA_COMMAND(cmd));
-	
-	param = g_new0(Parameter, 1);
-	param->name = g_strdup(name);
+gda_command_create_parameter (GdaCommand * cmd,
+			      gchar * name,
+			      GDA_ParameterDirection inout, GDA_Value * value)
+{
+	Parameter *param;
+
+	g_return_if_fail (GDA_IS_COMMAND (cmd));
+
+	param = g_new0 (Parameter, 1);
+	param->name = g_strdup (name);
 	param->inout = inout;
 	param->value = value;
-	
-	cmd->parameters = g_list_append(cmd->parameters, param);
-}
 
-/**
- * gda_command_get_timeout
- * @cmd the command object
- *
- * This function returns the timeout associated with the given
- * command object
- */
-glong
-gda_command_get_timeout (GdaCommand *cmd) {
-	CORBA_Environment ev;
-	glong ret;
-	
-	g_return_val_if_fail(IS_GDA_COMMAND(cmd), -1);
-	
-	CORBA_exception_init(&ev);
-	ret = GDA_Command__get_cmdTimeout(cmd->command, &ev);
-	gda_connection_corba_exception(gda_command_get_connection(cmd), &ev);
-	return (ret);
-}
-
-/**
- * gda_command_set_timeout
- * @cmd the command object
- * @timeout timeout
- *
- * Sets the timeout for the given command
- */
-void
-gda_command_set_timeout (GdaCommand *cmd, glong timeout) {
-	CORBA_Environment ev;
-	
-	g_return_if_fail(IS_GDA_COMMAND(cmd));
-	
-	CORBA_exception_init(&ev);
-	GDA_Command__set_cmdTimeout(cmd->command, (CORBA_long) timeout, &ev);
-	gda_connection_corba_exception(gda_command_get_connection(cmd), &ev);
+	cmd->parameters = g_list_append (cmd->parameters, param);
 }
