@@ -129,7 +129,7 @@ run_export_cb (gpointer user_data)
 		gda_command_set_cmd_type (cmd, GDA_COMMAND_TYPE_TABLE);
 		gda_command_set_text (cmd, name);
 
-		recset = gda_command_execute (cmd, &reccount, NULL);
+		recset = gda_command_execute (cmd, &reccount, 0);
 		if (!GDA_IS_RECORDSET (recset)) {
 			gda_command_free (cmd);
 			gda_export_stop (exp);
@@ -145,16 +145,18 @@ run_export_cb (gpointer user_data)
 			gchar *type;
 
 			gda_field = gda_recordset_field_idx (recset, cnt);
-			type = gda_fieldtype_2_string (NULL, 0, gda_field_type (gda_field));
+			type = gda_fieldtype_2_string (
+				NULL, 0, gda_field_get_gdatype (gda_field));
 
-			xml_field = gda_xml_database_table_add_field (exp->priv->tmp_xmldb,
-								      xml_table,
-								      gda_field_name (gda_field));
+			xml_field = gda_xml_database_table_add_field (
+				exp->priv->tmp_xmldb,
+				xml_table,
+				gda_field_get_name (gda_field));
 			gda_xml_database_field_set_gdatype (exp->priv->tmp_xmldb, xml_field, type);
 			gda_xml_database_field_set_size (exp->priv->tmp_xmldb, xml_field,
-							 gda_field_defined_size (gda_field));
+							 gda_field_get_defined_size (gda_field));
 			gda_xml_database_field_set_scale (exp->priv->tmp_xmldb, xml_field,
-							  gda_field_scale (gda_field));
+							  gda_field_get_scale (gda_field));
 
 			g_free (type);
 		}
