@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-sybase-connection.h,v 1.5.4.1 2001/09/16 20:12:39 rodrigo Exp $
+ * $Id: gda-sybase-connection.h,v 1.5.4.2 2001/11/22 12:12:26 rodrigo Exp $
  *
  * GNOME DB sybase Provider
  * Copyright (C) 2000 Rodrigo Moya
@@ -44,11 +44,15 @@
 
 typedef struct _sybase_Error
 {
-	guint err_type;
-	CS_CLIENTMSG cslib_msg;
-	CS_CLIENTMSG client_msg;
-	CS_SERVERMSG server_msg;
-	gchar *udeferr_msg;
+/*  	guint err_type; */
+
+/*  	CS_CLIENTMSG cslib_msg; */
+/*  	CS_CLIENTMSG client_msg; */
+/*  	CS_SERVERMSG server_msg */;
+/*  	gchar *udeferr_msg; */
+
+		gchar *eMessage;
+
 }
 sybase_Error;
 
@@ -112,4 +116,8 @@ gboolean gda_sybase_connection_reopen (GdaServerConnection *);
 CS_RETCODE gda_sybase_connection_select_database (GdaServerConnection *,
 						  const gchar * dbname);
 
+void gda_sybase_cleanup (sybase_Connection *, 
+                         CS_RETCODE, 
+                         const gchar *);
+
 #endif
