@@ -1,5 +1,5 @@
 /* 
- * $Id: gda-tds-connection.h,v 1.5 2001/07/18 23:05:43 vivien Exp $
+ * $Id: gda-tds-connection.h,v 1.5.4.1 2001/09/21 10:33:35 rodrigo Exp $
  *
  * GNOME DB tds Provider
  * Copyright (C) 2000 Holger Thon
@@ -61,7 +61,7 @@ typedef struct _tds_Connection
 	gboolean cs_diag;	// wether we can use cs_diag for cslib messages
 	gboolean ct_diag;	// wether we can use ct_diag for ctlib messages
 
-	GdaServerError *error;
+	GdaError *error;
 	tds_Error serr;
 
 	gchar *database;
@@ -79,7 +79,7 @@ gint gda_tds_connection_begin_transaction (GdaServerConnection * cnc);
 gint gda_tds_connection_commit_transaction (GdaServerConnection * cnc);
 gint gda_tds_connection_rollback_transaction (GdaServerConnection * cnc);
 GdaServerRecordset *gda_tds_connection_open_schema (GdaServerConnection * cnc,
-						    GdaServerError * error,
+						    GdaError * error,
 						    GDA_Connection_QType t,
 						    GDA_Connection_Constraint
 						    * constraints,
